@@ -121,7 +121,7 @@ gifconv_gif2lossless(unsigned char *gif_data, unsigned long gif_data_len,
     int palette_num = 0;
     int trans_index = -1;
     SavedImage Image;
-    int i;
+    int i, j;
     unsigned char *indices_data;
 
     gif_buff.data = gif_data;
@@ -134,6 +134,7 @@ gifconv_gif2lossless(unsigned char *gif_data, unsigned long gif_data_len,
     }
     if (DGifSlurp(GifFile) == GIF_ERROR) {
         fprintf(stderr, "gifconv_gif2lossless: DGifSlurp failed\n");
+        DGifCloseFile(GifFile);
         return NULL;
     }
     Image = GifFile->SavedImages[0];
@@ -144,6 +145,11 @@ gifconv_gif2lossless(unsigned char *gif_data, unsigned long gif_data_len,
     gif_width  = GifFile->SWidth;
     gif_height = GifFile->SHeight;
     bpp = ColorMap->BitsPerPixel;
+    if (bpp > 8) {
+        fprintf(stderr, "gifconv_gif2lossless: bpp=%d not implemented. accept only bpp <= 8\n", bpp);
+        DGifCloseFile(GifFile);
+        return NULL;
+    }
     palette_num = ColorMap->ColorCount;
 
     trans_index = getTransparentIndex(Image);
@@ -189,12 +195,16 @@ gifconv_gif2lossless(unsigned char *gif_data, unsigned long gif_data_len,
     }
     indices_data = malloc(((gif_width+ 3) & -4) * gif_height);
     gif_image_data_ref = Image.RasterBits;
+
     i = 0;
+    j = 0;
     for (y=0 ; y < gif_height ; y++) {
         for (x=0 ; x < gif_width ; x++) {
-            indices_data[x+y*((gif_width + 3) & -4)] = gif_image_data_ref[i];
+            indices_data[i] = gif_image_data_ref[j];
             i++;
+	    j++;
         }
+        while (i % 4) { i++; } // 4byte alignment
     }
     image_data = indices_data;
     /*
