@@ -201,7 +201,7 @@ swf_object_print(swf_object_t *swf) {
     }
 }
 
-extern unsigned char *
+unsigned char *
 swf_object_get_tagdata(swf_object_t *swf, int tag_seqno,
                        unsigned long *length) {
     int i;
@@ -306,12 +306,27 @@ swf_object_adjust_shapebitmap(swf_object_t *swf, int bitmap_id,
             }
         }
     }
+    return 0;
 }
 
+int
+swf_object_get_bitmap_size(swf_object_t *swf, int bitmap_id,
+                           int *width, int *height) {
+    swf_tag_t *tag;
+    int ret;
+    tag = swf_object_search_bitmap_tag(swf, bitmap_id);
+    if (tag == NULL) {
+        return 1;
+    }
+    if (tag->detail == NULL) {
+        swf_tag_create_input_detail(tag, swf);
+    }
+    ret = swf_tag_get_bitmap_size(tag, width, height);
+    return ret;
+}
 
 /* --- */
 
-
 int
 swf_object_replace_tagdata(swf_object_t *swf, int tag_seqno,
                            unsigned char *data, unsigned long *length) {
@@ -386,7 +401,9 @@ swf_object_replace_jpegdata(swf_object_t *swf, int image_id,
         return 1;
     }
     if (swf->shape_adjust_mode) {
-        swf_tag_create_input_detail(tag, swf);
+        if (tag->detail == NULL) {
+            swf_tag_create_input_detail(tag, swf);
+        }
         swf_tag_get_bitmap_size(tag, &old_width, &old_height);
         jpeg_size(jpeg_data, jpeg_data_len, &new_width, &new_height);
     }
@@ -446,7 +463,9 @@ swf_object_replace_pngdata(swf_object_t *swf, int image_id,
         return 1;
     }
     if (swf->shape_adjust_mode) {
-        swf_tag_create_input_detail(tag, swf);
+        if (tag->detail == NULL) {
+            swf_tag_create_input_detail(tag, swf);
+        }
         swf_tag_get_bitmap_size(tag, &old_width, &old_height);
         png_size(png_data, png_data_len, &new_width, &new_height);
     }
@@ -486,7 +505,9 @@ swf_object_replace_gifdata(swf_object_t *swf, int image_id,
         return 1;
     }
     if (swf->shape_adjust_mode) {
-        swf_tag_create_input_detail(tag, swf);
+        if (tag->detail == NULL) {
+            swf_tag_create_input_detail(tag, swf);
+        }
         swf_tag_get_bitmap_size(tag, &old_width, &old_height);
         gif_size(gif_data, gif_data_len, &new_width, &new_height);
     }
@@ -609,12 +630,22 @@ swf_object_get_actiondata(swf_object_t *swf, unsigned long *length, int tag_seqn
     if ((tag->tag != 12) &&  (tag->tag != 59)) { //  DoAction, DoInitAction
         return NULL;
     }
-    swf_tag_create_input_detail(tag, swf);
+    if (tag->detail == NULL) {
+        swf_tag_create_input_detail(tag, swf);
+    }
     swf_tag_action = (swf_tag_action_detail_t *) tag->detail;
     *length = swf_tag_action->action_record_len;
     return swf_tag_action->action_record;
 }
 
+int
+swf_object_insert_action_setvariables(swf_object_t *swf,
+                                      char **keys, char **values, int size) {
+    //
+    return 0;
+}
+
+
 int
 swf_object_apply_shapematrix_factor(swf_object_t *swf, int shape_id,
                                     double scale_x, double scale_y,
