@@ -45,8 +45,13 @@ extern void swf_tag_destroy(swf_tag_t *tag);
 extern int swf_tag_build(bitstream_t *bs, swf_tag_t *tag, struct swf_object_ *swf);
 extern void swf_tag_print(swf_tag_t *tag, struct swf_object_ *swf, int indent_depth);
 
+extern int swf_tag_identity(swf_tag_t *tag, int cid);
+
 /* image */
 
+extern int swf_tag_get_bitmap_size(swf_tag_t *tag,
+                                   int *width, int *height);
+
 extern unsigned char *swf_tag_get_jpeg_data(swf_tag_t *tag, unsigned long *length, int image_id, swf_tag_t *tag_jpegtables);
 extern unsigned char *swf_tag_get_alpha_data(swf_tag_t *tag, unsigned long *length, int image_id);
 extern int swf_tag_replace_jpeg_data(swf_tag_t *tag, int image_id,
@@ -84,4 +89,18 @@ extern int swf_tag_replace_edit_string(swf_tag_t *tag,
 
 extern int swf_tag_create_input_detail(swf_tag_t *tag, struct swf_object_ *swf);
 
+extern int swf_tag_apply_shape_matrix_factor(swf_tag_t *tag, int shape_id,
+                                             double scale_x, double scale_y,
+                                             double rotate_rad,
+                                             signed int trans_x,
+                                             signed int trans_y,
+                                             struct swf_object_ *swf);
+extern int swf_tag_apply_shape_rect_factor(swf_tag_t *tag, int shape_id,
+                                             double scale_x, double scale_y,
+                                             signed int trans_x,
+                                             signed int trans_y,
+                                             struct swf_object_ *swf);
+extern int swf_tag_apply_shape_type_tilled(swf_tag_t *tag, int shape_id,
+                                           struct swf_object_ *swf);
+
 #endif /* __SWF_TAG_H__ */
